@@ -25,7 +25,7 @@ def show(session: str, to_json: bool, id: str, tags: str, fields: str, otp: bool
         if not select:
             id = entries[0]["id"]
         else:
-            entries = list(map(lambda e: (f"{e['title']} ({e['id']})", e["id"]), sorted(entries, key=lambda entry: entry["title"])))  # type: ignore
+            entries = list(map(lambda e: (f"{e['vault']['name']}: {e['title']} ({e['id']})", e["id"]), sorted(entries, key=lambda entry: entry["title"])))  # type: ignore
             entry = inquirer.prompt([inquirer.List("entry", message="Select an entry", choices=entries)])
 
             id = entry["entry"]
